Module scrollbar

Module scrollbar 

Scrollbar widget - displays a scrollbar to control position within a range.

Structs

TkScrollbar
Refers to a scrollbar widget

Functions

make_horizontal_scrollbar
Creates an instance of an horizontal scrollbar in given parent item, connected to associated widget.
make_vertical_scrollbar
Creates an instance of a vertical scrollbar in given parent item, connected to associated widget.