Scrollbar widget - displays a scrollbar to control position within a range.
- also see the Tk manual
Structs
- TkScrollbar
- Refers to a scrollbar widget
Functions
- make_
horizontal_ scrollbar - Creates an instance of an horizontal scrollbar in given parent item, connected to associated widget.
- make_
vertical_ scrollbar - Creates an instance of a vertical scrollbar in given parent item, connected to associated widget.